==> node-jasmine_4.0.2+~cs7.10.3.orig-jasmine-core.tar.gz: jasmine-4.0.0/spec/html/ResultsNodeSpec.js <==
describe('ResultsNode', function() {
  it('wraps a result', function() {
    var fakeResult = {
        id: 123,
        message: 'foo'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    expect(node.result).toBe(fakeResult);
    expect(node.type).toEqual('suite');
  });

  it('can add children with a type', function() {
    var fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.children.length).toEqual(1);
    expect(node.children[0].result).toEqual(fakeChildResult);
    expect(node.children[0].type).toEqual('spec');
  });

  it('has a pointer back to its parent ResultNode', function() {
    var fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.children[0].parent).toBe(node);
  });

  it('can provide the most recent child', function() {
    var fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.last()).toBe(node.children[node.children.length - 1]);
  });
});

==> node-jasmine_4.5.0+~cs8.8.0.orig-jasmine-core.tar.gz: jasmine-4.5.0/spec/html/ResultsNodeSpec.js <==
describe('ResultsNode', function() {
  it('wraps a result', function() {
    const fakeResult = {
        id: 123,
        message: 'foo'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    expect(node.result).toBe(fakeResult);
    expect(node.type).toEqual('suite');
  });

  it('can add children with a type', function() {
    const fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.children.length).toEqual(1);
    expect(node.children[0].result).toEqual(fakeChildResult);
    expect(node.children[0].type).toEqual('spec');
  });

  it('has a pointer back to its parent ResultNode', function() {
    const fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.children[0].parent).toBe(node);
  });

  it('can provide the most recent child', function() {
    const fakeResult = {
        id: 123,
        message: 'foo'
      },
      fakeChildResult = {
        id: 456,
        message: 'bar'
      },
      node = new jasmineUnderTest.ResultsNode(fakeResult, 'suite', null);

    node.addChild(fakeChildResult, 'spec');

    expect(node.last()).toBe(node.children[node.children.length - 1]);
  });
});
